#
# bpk_feature.pl:  bpub keywords for stuff to go on Item pages
#
#  Feature: puts a pretty title and date at the top, and places images
#           before and after the text as found.  Images named
#           name.xxx, name_1.xxx, name_2.xxx, etc. are placed before, and
#           name_post.xxx, name_post_1.xxx, etc. are placed after, with
#           name being the feature name and xxx being jpg or gif.
#     content: the text to be featured
#     name (inheritable): the name of the feature
#     title (inheritable): text to be placed at the top-left
#     date (inheritable): text to be placed at the top-right
#
#  Photo: returns a page with a picture and a caption that is the same
#         as the inherited blurb, plus some optional additional text
#     name (inheritable): name of the feature
#     blurb (inheritable): caption for the picture
#     content (optional): additional text for the caption
#
#  Image: places an image, centered and on a new line
#     content: local name of the image file (no prefix or suffix)
#
#  Inlineimage: places an image inline
#     content: local name of the image file (no prefix or suffix)

package Feature;
@ISA = ("Keyword");

sub gettext {
    my ($self) = @_;
    my $content = $self->getpropertytext("content");
    my ($name,$title,$date) = $self->inheritpropertytext(qw(name title date));

    my ($uprefix,$sprefix) = $self->getprefix();
    my $headingfont= $self->getcreatetext("Font", name => "heading");
    my $smallheadingfont= $self->getcreatetext("Font", name => "smallheading");

    my $text .= <<"_eot_";
<table cellspacing="0" cellpadding="0" border="0" width="100%"><tr>
<td align="left"><i>$headingfont$title</font></i></td>
<td align="right"><i>$smallheadingfont$date</font></i></td>
</tr></table>
_eot_

    $text .= placeimage($self->tryimages("images/$sprefix$name"));
    for (my $count = 1;
	 my $img = $self->tryimages("images/$sprefix${name}_$count");
	 $count++) { $text .= placeimage($img) }

    $text .= $self->getcreatetext("Makepars", content => $content);

    $text .= placeimage($self->tryimages("images/$sprefix${name}_post"));
    for (my $count = 1;
	 my $img = $self->tryimages("images/$sprefix${name}_post_$count");
	 $count++) { $text .= placeimage($img) }

    return $text;
}

sub placeimage {
    my ($img) = @_;
    return "" unless $img;
    return <<"_eot_";
<p align="center"><img src="$$img{name}" width="$$img{width}"
                       height="$$img{height}" border="0"></p>
_eot_
}


package Photo;
@ISA = ("Keyword");

sub gettext {
    my ($self) = @_;
    my ($name,$blurb) = $self->inheritpropertytext(qw(name blurb));
    my $details = $self->trypropertytext("content");

    my $text = $self->getcreatetext("Image", content => $name);
    $text .= "<p>\n$blurb</p>\n";
    $text .= "<p>\n$details</p>\n" if $details;
    return $text;
}


package Image;
@ISA = ("Keyword");

sub gettext {
    my ($self) = @_;
    my $imagename = $self->getpropertytext("content");
    my $sprefix = $self->getsprefix();
    my $img = $self->getimages("images/$sprefix$imagename");
    return Feature::placeimage($img);
}


package Inlineimage;
@ISA = ("Keyword");

sub gettext {
    my ($self) = @_;
    my $imagename = $self->getpropertytext("content");
    my $sprefix = $self->getsprefix();
    my $img = $self->getimages("images/$sprefix$imagename");

    return <<"_eot_";
<img src="$$img{name}" width="$$img{width}" height="$$img{height}"
 valign="top" border="0">
_eot_
}


1;

