#
# bpk_htmlfile.pl:  bpub keywords for generating complete HTML pages
#
#  Htmlfile:  returns a complete html page.  ALL properties are optional.
#    title (inheritable):  page title
#    redirect:  if this page should be framed if accidently opened in the
#               top frame, this should be set to the page name (without
#               the .html suffix).  This will be ignored if a newwindow
#               property can be inherited.
#    meta:  anything to go in the HEAD section
#    refresh:  an url to replace this page, using <meta http-equiv="Refresh">
#    script:  any JavaScript code
#    frameset:  anything to be used in place of a body.  A no-frames
#               menu is added at the end.
#    bodytag:  a custom BODY tag.  If not given, a standard one is created.
#    border (boolean): if given, the body background color is the standard
#                      border color instead of white.
#    onload:  any JavaScript to go into the BODY onload handler
#    body:  stuff to go in the BODY section of the document
#    content:  stuff to go into the BODY section after going through
#              standard content page formatting
#
#  Frameset:  returns <FRAMESET ...> ... </FRAMESET>
#    rows or cols:  value for the FRAMESET's ROWS or COLS parameter
#    content:  stuff to go in the frameset, such as frames and other framesets
#
#  Frame:  returns a FRAME tag.  ALL properties are optional.
#    name:  frame name
#    src:  url of frame source
#    border (boolean):  src is set to "border.html"
#    blank (boolean):  src is set to "blank.html"
#    scroll (boolean):  scrolling is set to "auto" instead of "no"
#

package Htmlfile;
@ISA = ("Keyword");

sub gettext {
    my ($self) = @_;

    my ($title) = $self->tryinheritpropertytext("title");
    my ($redirect,$meta,$refresh,$script,$frameset,$bodytag,$border,$onload,
	$body,$content) = $self->trypropertytext(
  	  qw(redirect meta refresh script frameset bodytag border onload),
          qw(body content));

    if ($refresh) {
	$meta .= qq(<meta http-equiv="Refresh" content="0; URL=$refresh">\n);
    }
    if ($redirect and not $self->tryinheritproperty("newwindow")) {
	$onload = 'checkForFrame();' . ($onload || "");
	my $redirectpage = "index.html";
	if ($redirect =~ /^([^_]+)_/) { 
	    $redirectpage = "$1_index.html?$redirect";
	}
	$script .= <<"_eot_";

function checkForFrame() {
  if (window.location == top.location) {
    top.location.replace("$redirectpage");
  }
}
_eot_
    }

    my $text = "<html><head>\n";
    $text .= "<title>$title</title>\n" if defined $title;
    $text .= "$meta\n" if defined $meta;

    $text .= <<"_eot_" if defined $script;
<script language="JavaScript">
<!--
$script
// -->
</script>
_eot_

    $text .= "</head>\n\n";

    if (defined $frameset) {
	$text .= "$frameset\n" . noframesmenu();
    } else {
      if (defined $bodytag) { $text .= "$bodytag\n" }
      else {
        my $bgcolor = defined $border ? "#f8f8f8" : "#ffffff";
	if ($onload) { $onload .= ";" unless $onload =~ /\;$/ }
	else { $onload = "" }
	$text .= qq(<body bgcolor="$bgcolor" text="#000000" link="#830104"\n) .
	         qq( vlink="#830104" alink="#a33134"\n) .
	         qq( onload="window.status=' ';${onload}return true;") .
	         ">\n\n";
      }

      if (defined $body) { $text .= "$body\n" }
      elsif (defined $content) {
	my $font = $self->getcreatetext("Font");
	$text .= <<"_eot_";
<table cellspacing="0" cellpadding="0" border="0" width="100%">
<tr><td colspan="3" align="center" width="100%" height="20"><br></td></tr>
<tr><td width="20"><img src="images/etc/spacer.gif" width="20" height="2"></td>
<td width="100%">
$font
$content
</font>
</td>
<td width="20"><img src="images/etc/spacer.gif" width="20" height="2"></td>
</tr>
<tr><td colspan="3" align="center" width="100%" height="20"><br></td></tr>
</table>
_eot_

      }
      $text .= "</body>\n";
    }
    $text .= "</html>\n";
    return $text;
}


sub noframesmenu {
    return <<"_eot_";
<noframes>
<body>
This is Bret Victor's website.<br><br>
..............................................................
..............................................................
..............................................................
..............................................................
<br><br>

<b>I am what I create.</b><br>
<a href="create_software.html">Software</a><br>
<a href="create_electronics.html">Electronics</a><br>
<a href="create_research.html">Research</a><br>
<a href="create_music.html">Music</a><br>
<a href="create_humor.html">Humor</a><br>
<a href="create_other.html">Other</a><br><br>

<b>What else is there?</b><br>
<a href="else_who.html">Who I Am</a><br>
<a href="else_where.html">Where I Am</a><br>
<a href="else_current.html">Current Events</a><br>
<a href="else_photographs.html">Photographs</a><br>
<a href="else_links.html">Links</a><br>
<a href="else_about.html">About This Webpage</a><br><br>

</body>
</noframes>
_eot_
}


package Frameset;
@ISA = ("Keyword");

sub gettext {
    my ($self) = @_;
    my $content = $self->getpropertytext("content");
    my ($name, $value) = ("cols", $self->trypropertytext("cols"));
    ($name, $value) = ("rows", $self->getpropertytext("rows")) unless $value;
    return <<"_eot_";
<frameset frameborder="0" framespacing="0" border="0" $name="$value">
$content</frameset>
_eot_
}

package Frame;
@ISA = ("Keyword");

sub gettext {
    my ($self) = @_;
    my ($name, $src, $border, $blank, $scroll) =
      $self->trypropertytext(qw(name src border blank scroll));
    $src = "border.html" if defined $border;
    $src = "blank.html" if defined $blank;
    $scroll = defined $scroll ? "auto" : "no";

    my $text = qq(<frame marginwidth="0" marginheight="0" noresize\n);
    $text .= qq( scrolling="$scroll");
    $text .= qq( name="$name") if defined $name;
    $text .= qq( src="$src") if defined $src;
    $text .= ">\n";
    return $text;
}


