#
# bpk_index.pl:  bpub keywords for indexes and blogs
#
#  Index: returns an index page (heading, intro, items) after creating
#         item pages (with choosers) for each item
#     content: a block of Items
#     name: name of the section
#     title (inheritable): title of the index
#     intro (inheritable): text to be placed before the items
#     nochooser (optional): put only the index button, not arrows or
#                           balls, on the item pages
#     nochooserballs (optional): put only the index button and arrows, no balls
#     swaparrowlabels (optional): left arrow's subtext is "next", right
#                                 arrow's is "previous"
#
#  Item: container for an item in the index.  ALL properties are optional.
#     content: text to be made into the item page
#     link: external link to be used for the item (full href)
#     file: name of a local file to be used for the item
#     newwindow (boolean): item opens up in new window
#     header: text to be placed as a separator before the item
#     thumbnail: image to be used as the item thumbnail
#

package Index;
@ISA = ("Keyword");
$prefixproperty = "name";

sub gettext {
    my ($self) = @_;

    my ($name,$title,$intro)= $self->inheritpropertytext(qw(name title intro));
    my $nochooser = exists $$self{nochooser};
    my $nochooserballs = exists $$self{nochooserballs};
    my ($previousword, $nextword) =
      $$self{swaparrowlabels} ?  qw(next previous) : qw(previous next);
    my ($uprefix, $sprefix) = $self->getprefix();

    $self->attachsubpropertytext("content", qw(name title blurb));

    my ($iarrowimg,$larrowimg,$rarrowimg,$ballimg) =
      $self->getimages("images/chooser/chooser_indexarrow_blur",
		       "images/chooser/chooser_leftarrow_blur",
		       "images/chooser/chooser_rightarrow_blur",
		       "images/chooser/chooser_ball_blur");

    foreach $img ($iarrowimg,$larrowimg,$rarrowimg,$ballimg) {
	$$img{blur} = $$img{sharp} = $$img{name};
	$$img{sharp} =~ s/blur/sharp/;
    }

    my $contentblock = $$self{content};


    ###  calculate width and height of chooserball array

    my $chooserrows = scalar(@$contentblock) / 8;
    $chooserrows=int($chooserrows+1) unless $chooserrows == int($chooserrows);
    my $chooserwidth = 1;
    $chooserwidth = scalar(@$contentblock) / $chooserrows if $chooserrows;
    $chooserwidth=int($chooserwidth+1) unless
	$chooserwidth == int($chooserwidth);
    my $remainder = $chooserrows * $chooserwidth - scalar(@$contentblock);


    ###  create each item in the index

    my $itemcount = 0;
    foreach $item (@$contentblock) {
	next unless exists ($$item{content}) or exists ($$item{music});
	my $itemtext = $item->gettext();
        my ($chooser, $leftarrow, $rightarrow) = ("","","");

	### create the chooser to go at the bottom of this item

	unless ($nochooser) {
	    my $destitemcount = 0;
	    my $widthcount = 0;
	    my $rowscount = 0;
	    foreach $destitem (@$contentblock) {
		my $esctitle = $$destitem{_title};
		$esctitle =~ s/\'/\\\'/g;
		my $colon = $esctitle ? ":" : "";
		if (exists $$destitem{newwindow}) {
		    $esctitle .= " (new window)";
		}

		my $hrefline="href=\"$uprefix${name}_$$destitem{_name}.html\"";
		if ($$destitem{link}) {
		    my $link = $destitem->getpropertytext("link");
		    $hrefline = "href=\"$link\"";
		}
		if ($$destitem{newwindow}) {
		    $hrefline .= " target=\"_blank\"";
		}

		if ($widthcount >= $chooserwidth) {
		    $widthcount -= $chooserwidth;
		    $chooser .= "<td></td></tr>\n<tr><td></td>";
		    $chooser .= "<td></td>" if ($itemcount);
                    $rowscount++;
		    if ($rowscount == $chooserrows - 1) {
			$chooser .= "<td></td>" x $remainder;
		    }
		}
		if ($destitemcount == $itemcount) {
		    $chooser .= <<"_eot_";
<td width="$$ballimg{width}" height="$$ballimg{height}">
  <img src="$$ballimg{sharp}"
   width="$$ballimg{width}" height="$$ballimg{height}" border="0"></td>
_eot_
                } else {
		    $chooser .= <<"_eot_";
<td width="$$ballimg{width}" height="$$ballimg{height}"><a $hrefline
  onMouseOut="iblur('ball','_$destitemcount');window.status=' ';return true;"
  onMouseOver="isharp('ball','_$destitemcount');window.status='$esctitle';return true;">
  <img src="$$ballimg{blur}"
   width="$$ballimg{width}" height="$$ballimg{height}" border="0"
   name="ball_$destitemcount"></a></td>
_eot_
                    if ($destitemcount == $itemcount-1) {
			$leftarrow = <<"_eot_";
<td width="$$larrowimg{width}" height="$$larrowimg{height}"><a $hrefline
  onMouseOut="iblur('leftarrow','');window.status=' ';return true;"
  onMouseOver="isharp('leftarrow','');window.status='$previousword$colon $esctitle';return true;">
  <img src="$$larrowimg{blur}"
   width="$$larrowimg{width}" height="$$larrowimg{height}" border="0" name="leftarrow"></a></td>
_eot_
                    }
		    if ($destitemcount == $itemcount+1) {
			$rightarrow = <<"_eot_";
<td width="$$rarrowimg{width}" height="$$rarrowimg{height}"><a $hrefline
  onMouseOut="iblur('rightarrow','');window.status=' ';return true;"
  onMouseOver="isharp('rightarrow','');window.status='$nextword$colon $esctitle';return true;">
  <img src="$$rarrowimg{blur}"
   width="$$rarrowimg{width}" height="$$rarrowimg{height}" border="0"
   name="rightarrow"></a></td>
_eot_
                    }
		}
	    } continue { $destitemcount++; $widthcount++ }
	}

	###  append the chooser to the item text

	unless (exists $$item{newwindow}) {
	    if ($nochooserballs) { $chooser = "" }
	    $itemtext .= <<"_eot_";
<p><table align="center" cellspacing="0" cellpadding="0" border="0">
<tr>
<td width="$$iarrowimg{width}" height="$$iarrowimg{height}" align="left"><a
  href="$uprefix$name.html"
  onMouseOut="iblur('indexarrow','');window.status=' ';return true;"
  onMouseOver="isharp('indexarrow','');window.status='back to the $title index';return true;">
  <img src="$$iarrowimg{blur}"
   width="$$iarrowimg{width}" height="$$iarrowimg{height}" border="0"
   name="indexarrow"></a></td>
$leftarrow$chooser$rightarrow</tr></table></p>
_eot_
        }

	###  create the javascript to work the chooser

        my $script = <<"_eot_";
if (document.images) {
  indexarrow_blur = new Image($$iarrowimg{width},$$iarrowimg{height});
  indexarrow_blur.src = '$$iarrowimg{blur}';
  indexarrow_sharp = new Image($$iarrowimg{width},$$iarrowimg{height});
  indexarrow_sharp.src = '$$iarrowimg{sharp}';
_eot_
	$script .= <<"_eot_" unless $nochooser;
  leftarrow_blur = new Image($$larrowimg{width},$$larrowimg{height});
  leftarrow_blur.src = '$$larrowimg{blur}';
  leftarrow_sharp = new Image($$larrowimg{width},$$larrowimg{height}); 
  leftarrow_sharp.src = '$$larrowimg{sharp}';
  rightarrow_blur = new Image($$rarrowimg{width},$$rarrowimg{height});
  rightarrow_blur.src = '$$rarrowimg{blur}';
  rightarrow_sharp = new Image($$rarrowimg{width},$$rarrowimg{height}); 
  rightarrow_sharp.src = '$$rarrowimg{sharp}';
  ball_blur = new Image($$ballimg{width},$$ballimg{height}); 
  ball_blur.src = '$$ballimg{blur}';
  ball_sharp = new Image($$ballimg{width},$$ballimg{height}); 
  ball_sharp.src = '$$ballimg{sharp}';
_eot_
        $script .= <<"_eot_";
}

function iblur(name,suffix) {
  if (document.images) {
    document.images[name+suffix].src = eval(name+'_blur.src');
  }
}

function isharp(name,suffix) {
  if (document.images) {
    document.images[name+suffix].src = eval(name+'_sharp.src');
  }
}
_eot_

	###  create the file for the item

	my $filename = "$uprefix${name}_$$item{_name}";
	my $file = $item->getcreatetext("Htmlfile",
					title => $$item{_name},
					script => $script,
					content => $itemtext,
					redirect => $filename);
        $self->createfile("$filename.html",$file);

    } continue { $itemcount++ }


    ###  create the index file

    my $standardfont = $self->getcreatetext("Font");
    my $titlefont = $self->getcreatetext("Font", size => "+0", color => "");
    my $headingfont= $self->getcreatetext("Font", name => "heading");

    my $text = $self->getcreatetext("Heading", title => $title);
    $text .= $self->getcreatetext("Makepars", content => $intro);

    $text .= <<"_eot_" if @$contentblock;
<p><br><table cellspacing="0" cellpadding="0" border="0" width="100%">
_eot_

    foreach $item (@$contentblock) {
	unless ($item == $$contentblock[0]) {
	    $text .= qq(<tr><td colspan="4"><br></td></tr>\n);
	}
	my ($header,$newwindow) = $item->trypropertytext(qw(header newwindow));
	my $subtext = $item->trypropertytext("subtext") || $$item{_title};
	my $link = "$uprefix${name}_$$item{_name}.html";

	if ($$item{link}) {
	    $link = $item->getpropertytext("link");
	    $subtext = "";
	} elsif ($$item{file}) {
	    $link = "images/$sprefix${name}/" . $item->getpropertytext("file");
	    $subtext = "";
	}

	my $thumbimg;
	if (my $thumbnail = $item->trypropertytext("thumbnail")) {
	    $thumbimg = $self->getimages("images/$sprefix$name/thumbnails/".
					 "thumbnail_$thumbnail");
	} else {
	    $thumbimg = $self->tryimages("images/$sprefix$name/thumbnails/".
					 "thumbnail_$$item{_name}") ||
			$self->tryimages("images/$sprefix$name/thumbnails/".
					 "thumbnail_blank") ||
		        $self->getimages("images/etc/thumbnail_blank");
	}

	if ($header) { $text .= <<"_eot_" }
<tr><td colspan="4">$headingfont<i>$header</i></font></td><tr>
<tr><td colspan="4"><br></td></tr>
_eot_

	my $linktag = $item->getcreatetext("Link",
					   href => $link,
					   subtext => $subtext,
					   newwindow => $newwindow);
	$text .= <<"_eot_";
<tr><td width="10"><img src="images/etc/spacer.gif" width="10" height="2"></td>
<td width="$$thumbimg{width}" align="left" valign="top">$linktag<img
  src="$$thumbimg{name}" width="$$thumbimg{width}"
  height="$$thumbimg{height}" border="0"></a></td>
<td width="10"><img src="images/etc/spacer.gif" width="10" height="2"></td>
<td valign="top">
_eot_

	if (length $$item{_title}) {
	    $text .= "$titlefont$linktag$$item{_title}</a>: </font>";
	}

	$text .= <<"_eot_";
$standardfont
$$item{_blurb}
</font></td></tr>
_eot_
    }

    $text .= "</table></p>\n" if @$contentblock;
    return $text;
}


package Item;
@ISA = ("Container");



1;

