#
# bpk_pagespread.pl:  bpub keywords for doing a pagespread and subpages
#
#  Pagespread: returns the first page of the multipage set, after creating
#              files for all the other pages
#   content: a block of Pages
#   name (inheritable): name of the section
#   title (inheritable): title of the section
#
#  Page: container for a page in the spread
#   content: text of the page
#
#  Nextpage: returns a link to the next page in the spread
#   content: text of the link
#
#  Subpage: creates a file for the content, returns an empty string
#   content: text of the page
#   name: name for the subpage

package Pagespread;
@ISA = ("Keyword");
$prefixproperty = "name";

sub gettext {
    my ($self) = @_;
    my ($name, $title) = $self->inheritpropertytext(qw(name title));
    my ($uprefix, $sprefix) = $self->getprefix();
    my $contentblock = $self->getproperty("content");


    ###  create all pages except the first, and save as files

    my $count = 0;
    foreach $page (@$contentblock) {
	$$page{"_pagenum"} = $count;
	next unless $count;
	my $pagename = "$uprefix${name}_$count";
	my $pagecontent = $page->gettext();
	$pagecontent = $self->getcreatetext("Makepars", 
					    content => $pagecontent);

	my $pagefile = $self->getcreatetext("Htmlfile",
					    content => $pagecontent,
					    redirect => $pagename );
        $self->createfile("$pagename.html",$pagefile);
    } continue { $count++ }


    ###  generate first page and return it

    my $firstpage = $$contentblock[0];
    my $text = $self->getcreatetext("Heading", title => $title);
    my $content = $firstpage->getpropertytext("content");
    $text .= $self->getcreatetext("Makepars", content => $content);

    return $text;
}


package Page;
@ISA = ("Container");


package Nextpage;
@ISA = ("Keyword");

sub gettext {
    my ($self) = @_;
    my $uprefix = $self->getuprefix();
    my $content = $self->getpropertytext("content");
    my $pagenum = $self->inheritproperty("_pagenum") + 1;
    return $self->getcreatetext("Locallink",
				content => $content,
				subtext => $content,
				link => $pagenum,
				usepfx => 1 );
}

package Subpage;
@ISA = ("Keyword");

sub gettext {
    my ($self) = @_;
    my $pagename = $self->getuprefix() . $self->getpropertytext("name");
    my $file = $self->getcreatetext("Htmlfile",
				    content=>$self->getpropertytext("content"),
				    redirect => $pagename );
    $self->createfile("$pagename.html",$file);
    return "";
}

package Subpagelink;
@ISA = ("Keyword");

sub gettext {
    my ($self) = @_;
    $self->addpropertytext("link", $self->getpropertytext("name"));
    $self->addpropertytext("usepfx");
    return $self->getmorphtext("Locallink");
}


1;

